#
# spec file for package linphoneqt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   linphone
Name:           linphoneqt
Version:        4.1.1
Release:        lp152.6.2
Summary:        Qt interface for Linphone
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/SIP/Clients
Url:            https://linphone.org/
Source:         https://linphone.org/releases/sources/%{name}/%{name}-%{version}.tar.gz
Source1:        %{_name}.appdata.xml
# PATCH-FIX-UPSTREAM linphoneqt-fix-cmake-i18n.patch -- Support new CMake versions for translations (commit e70c077).
Patch0:         linphoneqt-fix-cmake-i18n.patch
# PATCH-FIX-UPSTREAM linphoneqt-force-default-style.patch boo#1083654 -- Force default theme style (commit 313aa68).
Patch1:         linphoneqt-force-default-style.patch
# PATCH-FIX-UPSTREAM linphoneqt-fix-qt-5.11.patch boo#1083654 -- Fix issues with Qt 5.10 and 5.11 (commits ecaab0f, d95f523, 5dd0161, 7f62ae9, 8720931, 4f908ef).
Patch2:         linphoneqt-fix-qt-5.11.patch
# PATCH-FIX-OPENSUSE linphoneqt-qt-5.9-fix-buttons.patch boo#1095273 -- Fix button invisibility with Qt 5.9.
Patch3:         linphoneqt-qt-5.9-fix-buttons.patch
# PATCH-FIX-OPENSUSE linphoneqt-fix-no-git.patch -- Fix building out-of-git.
Patch4:         linphoneqt-fix-no-git.patch
# PATCH-FIX-OPENSUSE fix-qm-generation.patch
Patch5:         fix-qm-generation.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel >= 5.9
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.9
BuildRequires:  pkgconfig(Qt5Core) >= 5.9
BuildRequires:  pkgconfig(Qt5DBus) >= 5.9
BuildRequires:  pkgconfig(Qt5Gui) >= 5.9
BuildRequires:  pkgconfig(Qt5Network) >= 5.9
BuildRequires:  pkgconfig(Qt5Quick) >= 5.9
BuildRequires:  pkgconfig(Qt5QuickControls2) >= 5.9
BuildRequires:  pkgconfig(Qt5Svg) >= 5.9
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.9
BuildRequires:  pkgconfig(linphone) >= 3.12.0
BuildRequires:  pkgconfig(mediastreamer) >= 2.16.0

%description
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%package -n %{_name}
Summary:        Web Phone
Group:          Productivity/Telephony/SIP/Clients
Requires:       lib%{_name}-data
Requires:       libqt5-qtgraphicaleffects
Requires:       libqt5-qtquickcontrols
Requires:       libqt5-qtquickcontrols2
Recommends:     %{_name}-cli
Obsoletes:      %{_name}-lang < %{version}

%description -n %{_name}
Linphone is a Web phone with a Qt interface. It lets you make
two-party calls over IP networks such as the Internet. It uses the IETF
protocols SIP (Session Initiation Protocol) and RTP (Realtime TransporT
Protocol) to make calls, so it should be able to communicate with other
SIP-based Web phones. With several codecs available, it can be used
with high speed connections as well as 28k modems.

%prep
%autosetup -p1
cp %{SOURCE1} linphone.appdata.xml

%build
%cmake \
  -DENABLE_DBUS=ON                 \
  -DENABLE_PRECOMPILED_HEADERS=OFF \
  -DENABLE_STRICT=OFF              \
  -DENABLE_STATIC=OFF
make %{?_smp_mflags} V=1

%install
%cmake_install
install -Dpm 0644 linphone.appdata.xml \
  %{buildroot}%{_datadir}/metainfo/linphone.appdata.xml

%if 0%{?suse_version} < 1500
%post -n %{_name}
%desktop_database_post
%icon_theme_cache_post

%postun -n %{_name}
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files -n %{_name}
%license LICENSE
%doc README.md
%{_bindir}/linphone
%{_bindir}/linphone-tester
%{_datadir}/linphone/
%{_datadir}/applications/linphone.desktop
%{_datadir}/icons/hicolor/*/apps/linphone.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/linphone.appdata.xml

%changelog
* Sat Aug 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add fix-qm-generation.patch to fix abort on startup (boo#1140595)
* Wed Aug 15 2018 sor.alexei@meowr.ru
- Add linphoneqt-fix-no-git.patch: Fix building out-of-git.
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Change the RPM group to the more appropriate and precise
  Productivity/Telephony/SIP/Clients.
* Sun Aug 12 2018 sor.alexei@meowr.ru
- Add linphoneqt-force-default-style.patch: Force default theme
  style (commit 313aa68).
  This fixes issues with tabs reported in boo#1095273.
* Sat Aug  4 2018 sor.alexei@meowr.ru
- Add linphoneqt-qt-5.9-fix-buttons.patch: Fix button invisibility
  with Qt 5.9 (boo#1095273).
- Improve linphoneqt-fix-qt-5.11.patch: Add a fix for
  DefaultTranslator dealing with Qt 5.9 (commit d95f523).
* Thu Aug  2 2018 sor.alexei@meowr.ru
- Replace linphoneqt-fix-qt-5.10.patch with
  linphoneqt-fix-qt-5.11.patch, adding more fixes:
  * Try to support menu bar on Qt 5.10 (commit 5dd0161).
  * Fix ComboBox by importing named QtQuick.Controls (commit
    7f62ae9).
  * Do not use SignalSpy as click is emitted twice instead of one
    in Qt 5.11 (commit 8720931),
  * Avoid a crash in Calls with a bad binding (Qt 5.11) on
    ConferenceControls (commit 4f908ef).
- Do not bother installing the appstream file to
  /usr/share/appdata/ on openSUSE Leap 42.x or older.
* Thu Mar  8 2018 sor.alexei@meowr.ru
- Add linphoneqt-fix-qt-5.10.patch: Rename the icon property of
  TabButton to iconName (an issue with Qt 5.10 and the new icon
  property, commit ecaab0f, boo#1083654).
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Add the missing libqt5-qtquickcontrols dependency (boo#1065173).
- Install the appstream file to the /usr/share/metainfo/ directory
  on openSUSE Leap 15.x or newer.
* Sun Sep 10 2017 sor.alexei@meowr.ru
- Add linphoneqt-fix-cmake-i18n.patch: Support new CMake versions
  for translations (commit e70c077).
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Initial package.
